==> jc-unilever-client-0.1.412-sources.jar: com/xforceplus/ultraman/app/jcunilever/controller/OrderDetailFeignApi.java <==
package com.xforceplus.ultraman.app.jcunilever.controller;


/**
 * 订单明细feign客户端
 *
 * @author ultraman
 * @date 2023-06-07
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jcunilever.entity.OrderDetail;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-unilever")
public interface OrderDetailFeignApi {

  /**
   * 通过id查询订单明细
   * @param  id
   * @return R
   */
  @GetMapping("/orderDetail/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增订单明细
   * @param orderDetail 订单明细
   * @return R
   */
  @PostMapping("/orderDetail/add")
  public R save(@RequestBody OrderDetail orderDetail);

  /**
   * 修改订单明细
   * @param orderDetail 订单明细
   * @return R
   */
  @PostMapping("/orderDetail/update")
  public R updateById(@RequestBody OrderDetail orderDetail);

  /**
   * 通过id删除订单明细
   * @param  id
   * @return R
   */
  @DeleteMapping("/orderDetail/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-unilever-client-0.1.669-sources.jar: com/xforceplus/ultraman/app/jcunilever/controller/OrderDetailFeignApi.java <==
package com.xforceplus.ultraman.app.jcunilever.controller;


/**
 * DTC业务feign客户端
 *
 * @author ultraman
 * @date 2023-11-29
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jcunilever.entity.OrderDetail;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-unilever")
public interface OrderDetailFeignApi {

  /**
   * 通过id查询DTC业务
   * @param  id
   * @return R
   */
  @GetMapping("/orderDetail/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增DTC业务
   * @param orderDetail DTC业务
   * @return R
   */
  @PostMapping("/orderDetail/add")
  public R save(@RequestBody OrderDetail orderDetail);

  /**
   * 修改DTC业务
   * @param orderDetail DTC业务
   * @return R
   */
  @PostMapping("/orderDetail/update")
  public R updateById(@RequestBody OrderDetail orderDetail);

  /**
   * 通过id删除DTC业务
   * @param  id
   * @return R
   */
  @DeleteMapping("/orderDetail/del/{id}" )
  public R removeById(@PathVariable Long id);

}
